//
//  NativeViewFactory.swift
//  Runner
//
//  Created by Andrey Khaynus on 08.01.2020.
//  Copyright © 2020 The Chromium Authors. All rights reserved.
//

import Flutter
import Foundation

class NativeViewFactory : NSObject, FlutterPlatformViewFactory {

    let messenger: FlutterBinaryMessenger

    init(messenger: FlutterBinaryMessenger) {
        self.messenger = messenger
    }

    public func create(withFrame frame: CGRect, viewIdentifier viewId: Int64, arguments args: Any?) -> FlutterPlatformView {
        return NativeView(frame, viewId:viewId,
                          args:args as? [String: Any] ?? [:],
                          messenger: messenger)
    }

    func createArgsCodec() -> FlutterMessageCodec & NSObjectProtocol {
        return FlutterStandardMessageCodec.sharedInstance()
    }
}

public class NativeView : NSObject, FlutterPlatformView, MPAdViewDelegate {


    let controller: FlutterViewController

    private var adView : MPAdView?
    private let frame : CGRect
    private let viewId: Int64
    private let channel: FlutterMethodChannel
    private let args: [String: Any]

    init(_ frame:CGRect, viewId:Int64, args: [String: Any], messenger: FlutterBinaryMessenger){
        self.args = args
        self.frame = frame
        self.viewId = viewId
        controller = FlutterViewController()
        channel = FlutterMethodChannel(name: "mopub_banner_view_\(viewId)", binaryMessenger: messenger)
    }

    public func view() -> UIView {
        return getBanner() ?? UIView()
    }

    fileprivate func getBanner() -> MPAdView? {
        if adView == nil {
            let placementId = self.args["adUnitID"] as? String ?? "unknownId100500"
            adView = MPAdView(adUnitId: placementId)
            channel.setMethodCallHandler{(call, result) in
                switch call.method {
                case "loadBanner":
                    print("sometag loadBanner method call")
                    self.adView?.loadAd()
                    break
                case "dispose":
                    self.dispose()
                    print("sometag dispose method call")
                    break
                default:
                    result(FlutterMethodNotImplemented)
                    print("sometag unknown method call")
                    break

                }
            }
        }
        print("sometag return Ad view")
        return adView
    }

    public func viewControllerForPresentingModalView() -> UIViewController? {
        return UIApplication.shared.keyWindow?.rootViewController
    }

    fileprivate func dispose() {
        adView?.removeFromSuperview()
        adView = nil
        channel.setMethodCallHandler(nil)
    }

    public func adViewDidLoadAd(_ view: MPAdView!, adSize: CGSize) {
        print("sometag loaded")
    }


    public func adView(_ view: MPAdView!, didFailToLoadAdWithError error: Error!) {
//        self.testView.backgroundColor = UIColor.red
        print("EeeeeeeeeeEeEeeeeeeeeeeeE")

        print(error.localizedDescription)
    }


}


//protocol TestableDelegate {
//
//    func output()
//
//}


//class TestView: UIView {
//
//
//  var delegate: TestableDelegate?
//
//
//    func load() {
//        self.backgroundColor = .red
//        DispatchQueue.main.asyncAfter(deadline: .now() + .seconds(1)) {
//            self.delegate?.output()
//        }
//
//    }
//
//
//}





