import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';

class Mopub {
  static const MethodChannel _channel =
      const MethodChannel('mopub');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

typedef MopubBannerViewCreatedCallback = void Function(BannerAdController controller);

class MopubBannerView extends StatefulWidget {

  static const String _viewType = "mopub_banner_view";

  final String adUnitID;

  final MopubBannerViewCreatedCallback onCreate;

  MopubBannerView({
    Key key,
    @required this.adUnitID,
    this.onCreate
  })
      : assert(adUnitID.isNotEmpty),
        super(key: key);

  @override
  _MopubBannerViewState createState() => _MopubBannerViewState();
}

class _MopubBannerViewState extends State<MopubBannerView> {

//  double containerHeight = 0;
//  final MethodChannel _channel;
//
//  NativeAdController._(int id) : _channel = new MethodChannel("mopub_banner_view_$id");

  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
        child: AndroidView(
          viewType: MopubBannerView._viewType,
          onPlatformViewCreated: _onPlatformViewCreated,
          creationParamsCodec: StandardMessageCodec(),
          creationParams: {
            "adUnitID": widget.adUnitID,
          },
        ),

        height: 250,
      );


    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
        child: UiKitView(
          viewType: MopubBannerView._viewType,
          onPlatformViewCreated: _onPlatformViewCreated,
          creationParamsCodec: StandardMessageCodec(),
          creationParams: {
            "adUnitID": widget.adUnitID,
          },
        ),

        height: 250,
      );
    }

    return Text('$defaultTargetPlatform is not supported PlatformView yet.');
  }

  _onPlatformViewCreated(int id) {
    print('sometag _onPlatformViewCreated $id');
    if (widget.onCreate != null)
      print('sometag _onPlatformViewCreated $id part2');
    widget.onCreate(BannerAdController._(id));
  }
}

class MopubBanner {

  static MopubBanner _instance;

  factory MopubBanner() => _instance ??= MopubBanner._();

  MopubBanner._();

  final _channel = MethodChannel("flutter_banner_mopub");

  Future<Null> initialize({String appID}) async {
    print('sometag initialize sdk');
    await _channel.invokeMethod("initialize", {});
    return null;
  }
}

class BannerAdController {

  final MethodChannel _channel;

  BannerAdController._(int id) : _channel = new MethodChannel("mopub_banner_view_$id");

  Future<Null> loadBanner() async {
    print('sometag try to load banner');

    await _channel.invokeMethod("loadBanner");
    return null;
  }

  Future<dynamic> onBannerLoaded(MethodCall call) {

    //change container size
    return null;
  }
}
